summaryrefslogtreecommitdiffstats
path: root/lib/auto/testcase/resiliency/AutoResilMain.py
diff options
context:
space:
mode:
authorGerard Damm <gerard.damm@wipro.com>2018-03-20 16:06:10 -0500
committerGerard Damm <gerard.damm@wipro.com>2018-03-20 16:06:10 -0500
commit05a3cd97eca82ab63f1733b55b38f026928ce2f6 (patch)
tree6b823338b44a4aedea88084b93be53ad3b0a5221 /lib/auto/testcase/resiliency/AutoResilMain.py
parente1730ab6e1b355baec45def4f0ed305998895a77 (diff)
structures for definition code (Tests and Challenges)
JIRA: AUTO-13 Created structures for configuring various test definition scripts and challenge definition scripts in corresponding classes (something like libraries of functions, with an index ID to pick the applicable function). This will be useful to leverage Python clients to OpenStack and Kubernetes, or even for HTTP-level APIs for ONAP. It may be more flexible than the list of CLI/API commands initially planned (however, the list structures are still there, and might be used by the scripts). Additionally, there are some test snippets for Openstack Python SDK (work in progress). Also, there is a clouds.yaml file, for this interface. Change-Id: Ida1ff118fcbfe8715679492feb8fe0df2da62b45 Signed-off-by: Gerard Damm <gerard.damm@wipro.com>
Diffstat (limited to 'lib/auto/testcase/resiliency/AutoResilMain.py')
-rw-r--r--lib/auto/testcase/resiliency/AutoResilMain.py7
1 files changed, 5 insertions, 2 deletions
diff --git a/lib/auto/testcase/resiliency/AutoResilMain.py b/lib/auto/testcase/resiliency/AutoResilMain.py
index 03e7151..2f67bdf 100644
--- a/lib/auto/testcase/resiliency/AutoResilMain.py
+++ b/lib/auto/testcase/resiliency/AutoResilMain.py
@@ -164,8 +164,11 @@ def main():
print("Problem with test definition: empty")
sys.exit() # stop entire program, because test definition MUST be correct
else:
- # TODO run test: method of TestDefinition, or function ?
- pass
+ # TODO run test: call selected test definition run_test_code() method
+ test_def = get_indexed_item_from_list(selected_test_def_ID, AutoResilGlobal.test_definition_list)
+ if test_def != None:
+ test_def.run_test_code()
+
else:
print("No current selection of Test Definition. Try again.")
continue